==> daikon-1.0.2.tar.gz: daikon-1.0.2/src/Library.h <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef __LIBRARY_H__INCLUDED__
#define __LIBRARY_H__INCLUDED__

#include <SDL/SDL.h>
#include <map>
#include <string>

using namespace std;

class Library
{
private:
    Library();
    ~Library();

    static bool initialized;
    static void end();

    static map<string, SDL_Surface*> images;
    static map<string, SDLKey> keyboardMap;

public:
    static void init();
    static SDL_Surface* createWindow(Uint32 width, Uint32 height);
    static SDL_Surface* createSurface(Uint32 width, Uint32 height);
    static SDL_Surface* createSurface32(Uint32 width, Uint32 height);
    static SDL_Surface* createSurface16(Uint32 width, Uint32 height);
    static SDL_Surface* createSurface8(Uint32 width, Uint32 height);
    static SDL_Surface* createString(const char* text);
    static SDL_Surface* createString(const char* text, SDL_Color* color);
    static SDL_Surface* createLargeString(const char* text);
    static SDL_Surface* createHugeString(const char* text);
    static SDL_Surface* loadImage(const string& file);
    static void blitSurface(SDL_Surface*& src, SDL_Rect* srcrect, SDL_Surface*& dist, SDL_Rect* distrect);
    static void freeImages();
    static SDLKey getKeySym(string name);
};
#endif

==> daikon-1.1.tar.gz: daikon-1.1/src/Library.h <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef __LIBRARY_H__INCLUDED__
#define __LIBRARY_H__INCLUDED__

#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>
#include <map>
#include <string>

using namespace std;

class Library
{
private:
    Library();
    ~Library();

    static bool initialized;
    static void end();

    static map<string, SDL_Surface*> images;
    static map<string, SDLKey> keyboardMap;

public:
    static void init();
    static SDL_Surface* createWindow(Uint32 width, Uint32 height);
    static SDL_Surface* createString(const char* text);
    static SDL_Surface* createString(const char* text, const SDL_Color* color);
    static SDL_Surface* createFilledString(const char* text, const SDL_Color& fg, const SDL_Color& bg);
    static SDL_Surface* createString(const char* text, const char* fontPath, int size, const SDL_Color& color, int style);
    static TTF_Font* getSystemFont();
    static SDL_Surface* loadImage(const string& file);
    static void freeImages();
    static SDLKey getKeySym(string name);
};
#endif
